
# aimodelshare
### The mission of the AI Model Share Platform (website w/ integrated Python library) is to provide a trusted non profit repository for machine learning model prediction APIs (python library + integrated website at modelshare.org.  A beta version of the platform is currently being used by Columbia University students, faculty, and staff to test and improve platform functionality.

### In a matter of seconds, data scientists can launch a model into this infrastructure and end-users the world over will be able to engage their machine learning models.

* ***Launch machine learning models into scalable production ready prediction REST APIs using a single Python function.***

* ***Details about each model, how to use the model's API, and the model's author(s) are deployed simultaneously into a searchable website at modelshare.org.***

* ***Deployed models receive an individual Model Playground listing information about all deployed models. Each of these pages includes a fully functional prediction dashboard that allows end-users to input text, tabular, or image data and receive live predictions.***

* ***Moreover, users can build on model playgrounds by 1) creating ML model competitions, 2) uploading Jupyter notebooks to share code, 3) sharing model architectures and 4) sharing data... with all shared artifacts automatically creating a data science user portfolio.***

# Use the aimodelshare Python library to deploy your model, create a new ML competition, and more.
* [Tutorials for deploying models](https://www.modelshare.org/search/deploy?search=ALL&problemdomain=ALL&gettingstartedguide=TRUE&pythonlibrariesused=ALL&tags=ALL&pageNum=1).

# Find model playground web-dashboards to generate predictions now.
* [View deployed models and generate predictions at modelshare.org](https://www.modelshare.org)

# Installation

You can then install aimodelshare from PyPi
```
pip install aimodelshare
```

